pub struct EndpointMatcherMetadataLabelMatcherMetadataLabels {
pub label_name: Option<String>,
pub label_value: Option<String>,
}Expand description
Defines a name-pair value for a single label.
This type is not used in any activity, and only used as part of another schema.
Fields
label_name: Option<String>Required. Label name presented as key in xDS Node Metadata.
label_value: Option<String>Required. Label value presented as value corresponding to the above key, in xDS Node Metadata.