pub struct ExtensionChainMatchCondition {
pub cel_expression: Option<String>,
}Expand description
Conditions under which this chain is invoked for a request.
This type is not used in any activity, and only used as part of another schema.
Fields
cel_expression: Option<String>Required. A Common Expression Language (CEL) expression that is used to match requests for which the extension chain is executed. For more information, see CEL matcher language reference.