pub struct GrpcRouteHeaderMatch {
pub key: Option<String>,
pub type_: Option<String>,
pub value: Option<String>,
}Expand description
A match against a collection of headers.
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>Required. The key of the header.
type_: Option<String>Optional. Specifies how to match against the value of the header. If not specified, a default value of EXACT is used.
value: Option<String>Required. The value of the header.