pub struct GrpcRouteMethodMatch {
pub case_sensitive: Option<bool>,
pub grpc_method: Option<String>,
pub grpc_service: Option<String>,
pub type_: Option<String>,
}Expand description
Specifies a match against a method.
This type is not used in any activity, and only used as part of another schema.
Fields
case_sensitive: Option<bool>Optional. Specifies that matches are case sensitive. The default value is true. case_sensitive must not be used with a type of REGULAR_EXPRESSION.
grpc_method: Option<String>Required. Name of the method to match against. If unspecified, will match all methods.
grpc_service: Option<String>Required. Name of the service to match against. If unspecified, will match all services.
type_: Option<String>Optional. Specifies how to match against the name. If not specified, a default value of “EXACT” is used.