pub struct HttpRouteFaultInjectionPolicyAbort {
pub http_status: Option<i32>,
pub percentage: Option<i32>,
}Expand description
Specification of how client requests are aborted as part of fault injection before being sent to a destination.
This type is not used in any activity, and only used as part of another schema.
Fields
http_status: Option<i32>The HTTP status code used to abort the request. The value must be between 200 and 599 inclusive.
percentage: Option<i32>The percentage of traffic which will be aborted. The value must be between [0, 100]