pub struct HttpRouteHeaderMatch {
pub exact_match: Option<String>,
pub header: Option<String>,
pub invert_match: Option<bool>,
pub prefix_match: Option<String>,
pub present_match: Option<bool>,
pub range_match: Option<HttpRouteHeaderMatchIntegerRange>,
pub regex_match: Option<String>,
pub suffix_match: Option<String>,
}Expand description
Specifies how to select a route rule based on HTTP request headers.
This type is not used in any activity, and only used as part of another schema.
Fields
exact_match: Option<String>The value of the header should match exactly the content of exact_match.
header: Option<String>The name of the HTTP header to match against.
invert_match: Option<bool>If specified, the match result will be inverted before checking. Default value is set to false.
prefix_match: Option<String>The value of the header must start with the contents of prefix_match.
present_match: Option<bool>A header with header_name must exist. The match takes place whether or not the header has a value.
range_match: Option<HttpRouteHeaderMatchIntegerRange>If specified, the rule will match if the request header value is within the range.
regex_match: Option<String>The value of the header must match the regular expression specified in regex_match. For regular expression grammar, please see: https://github.com/google/re2/wiki/Syntax
suffix_match: Option<String>The value of the header must end with the contents of suffix_match.