pub struct HttpRouteQueryParameterMatch {
pub exact_match: Option<String>,
pub present_match: Option<bool>,
pub query_parameter: Option<String>,
pub regex_match: Option<String>,
}Expand description
Specifications to match a query parameter in the request.
This type is not used in any activity, and only used as part of another schema.
Fields
exact_match: Option<String>The value of the query parameter must exactly match the contents of exact_match. Only one of exact_match, regex_match, or present_match must be set.
present_match: Option<bool>Specifies that the QueryParameterMatcher matches if request contains query parameter, irrespective of whether the parameter has a value or not. Only one of exact_match, regex_match, or present_match must be set.
query_parameter: Option<String>The name of the query parameter to match.
regex_match: Option<String>The value of the query parameter must match the regular expression specified by regex_match. For regular expression grammar, please see https://github.com/google/re2/wiki/Syntax Only one of exact_match, regex_match, or present_match must be set.