HttpRouteRedirect

Struct HttpRouteRedirect 

pub struct HttpRouteRedirect {
    pub host_redirect: Option<String>,
    pub https_redirect: Option<bool>,
    pub path_redirect: Option<String>,
    pub port_redirect: Option<i32>,
    pub prefix_rewrite: Option<String>,
    pub response_code: Option<String>,
    pub strip_query: Option<bool>,
}
The specification for redirecting traffic.

This type is not used in any activity, and only used as part of another schema.

Fields

host_redirect: Option<String>

The host that will be used in the redirect response instead of the one that was supplied in the request.

https_redirect: Option<bool>

If set to true, the URL scheme in the redirected request is set to https. If set to false, the URL scheme of the redirected request will remain the same as that of the request. The default is set to false.

path_redirect: Option<String>

The path that will be used in the redirect response instead of the one that was supplied in the request. path_redirect can not be supplied together with prefix_redirect. Supply one alone or neither. If neither is supplied, the path of the original request will be used for the redirect.

port_redirect: Option<i32>

The port that will be used in the redirected request instead of the one that was supplied in the request.

prefix_rewrite: Option<String>

Indicates that during redirection, the matched prefix (or path) should be swapped with this value. This option allows URLs be dynamically created based on the request.

response_code: Option<String>

The HTTP Status code to use for the redirect.

strip_query: Option<bool>

if set to true, any accompanying query portion of the original URL is removed prior to redirecting the request. If set to false, the query portion of the original URL is retained. The default is set to false.