pub struct HttpRouteRequestMirrorPolicy {
pub destination: Option<HttpRouteDestination>,
pub mirror_percent: Option<f32>,
}Expand description
Specifies the policy on how requests are shadowed to a separate mirrored destination service. The proxy does not wait for responses from the shadow service. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow. Mirroring is currently not supported for Cloud Run destinations.
This type is not used in any activity, and only used as part of another schema.
Fields
destination: Option<HttpRouteDestination>The destination the requests will be mirrored to. The weight of the destination will be ignored.
mirror_percent: Option<f32>Optional. The percentage of requests to get mirrored to the desired destination.