HttpRouteRouteAction

Struct HttpRouteRouteAction 

pub struct HttpRouteRouteAction {
Show 13 fields pub cors_policy: Option<HttpRouteCorsPolicy>, pub destinations: Option<Vec<HttpRouteDestination>>, pub direct_response: Option<HttpRouteHttpDirectResponse>, pub fault_injection_policy: Option<HttpRouteFaultInjectionPolicy>, pub idle_timeout: Option<Duration>, pub redirect: Option<HttpRouteRedirect>, pub request_header_modifier: Option<HttpRouteHeaderModifier>, pub request_mirror_policy: Option<HttpRouteRequestMirrorPolicy>, pub response_header_modifier: Option<HttpRouteHeaderModifier>, pub retry_policy: Option<HttpRouteRetryPolicy>, pub stateful_session_affinity: Option<HttpRouteStatefulSessionAffinityPolicy>, pub timeout: Option<Duration>, pub url_rewrite: Option<HttpRouteURLRewrite>,
}
The specifications for routing traffic and applying associated policies.

This type is not used in any activity, and only used as part of another schema.

Fields

cors_policy: Option<HttpRouteCorsPolicy>

The specification for allowing client side cross-origin requests.

destinations: Option<Vec<HttpRouteDestination>>

The destination to which traffic should be forwarded.

direct_response: Option<HttpRouteHttpDirectResponse>

Optional. Static HTTP Response object to be returned regardless of the request.

fault_injection_policy: Option<HttpRouteFaultInjectionPolicy>

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced on a percentage of requests before sending those requests to the backend service. Similarly requests from clients can be aborted for a percentage of requests. timeout and retry_policy will be ignored by clients that are configured with a fault_injection_policy

idle_timeout: Option<Duration>

Optional. Specifies the idle timeout for the selected route. The idle timeout is defined as the period in which there are no bytes sent or received on either the upstream or downstream connection. If not set, the default idle timeout is 1 hour. If set to 0s, the timeout will be disabled.

redirect: Option<HttpRouteRedirect>

If set, the request is directed as configured by this field.

request_header_modifier: Option<HttpRouteHeaderModifier>

The specification for modifying the headers of a matching request prior to delivery of the request to the destination. If HeaderModifiers are set on both the Destination and the RouteAction, they will be merged. Conflicts between the two will not be resolved on the configuration.

request_mirror_policy: Option<HttpRouteRequestMirrorPolicy>

Specifies the policy on how requests intended for the routes destination are shadowed to a separate mirrored destination. Proxy will not wait for the shadow destination to respond before returning the response. Prior to sending traffic to the shadow service, the host/authority header is suffixed with -shadow.

response_header_modifier: Option<HttpRouteHeaderModifier>

The specification for modifying the headers of a response prior to sending the response back to the client. If HeaderModifiers are set on both the Destination and the RouteAction, they will be merged. Conflicts between the two will not be resolved on the configuration.

retry_policy: Option<HttpRouteRetryPolicy>

Specifies the retry policy associated with this route.

stateful_session_affinity: Option<HttpRouteStatefulSessionAffinityPolicy>

Optional. Specifies cookie-based stateful session affinity.

timeout: Option<Duration>

Specifies the timeout for selected route. Timeout is computed from the time the request has been fully processed (i.e. end of stream) up until the response has been completely processed. Timeout includes all retries.

url_rewrite: Option<HttpRouteURLRewrite>

The specification for rewrite URL before forwarding requests to the destination.