pub struct HttpRouteURLRewrite {
pub host_rewrite: Option<String>,
pub path_prefix_rewrite: Option<String>,
}Expand description
The specification for modifying the URL of the request, prior to forwarding the request to the destination.
This type is not used in any activity, and only used as part of another schema.
Fields
host_rewrite: Option<String>Prior to forwarding the request to the selected destination, the requests host header is replaced by this value.
path_prefix_rewrite: Option<String>Prior to forwarding the request to the selected destination, the matching portion of the requests path is replaced by this value.