pub struct ListAuthzExtensionsResponse {
pub authz_extensions: Option<Vec<AuthzExtension>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
Message for response to listing AuthzExtension resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations authz extensions list projects (response)
Fields
authz_extensions: Option<Vec<AuthzExtension>>The list of AuthzExtension resources.
next_page_token: Option<String>A token identifying a page of results that the server returns.
unreachable: Option<Vec<String>>Locations that could not be reached.