pub struct ListLbEdgeExtensionsResponse {
pub lb_edge_extensions: Option<Vec<LbEdgeExtension>>,
pub next_page_token: Option<String>,
pub unreachable: Option<Vec<String>>,
}Expand description
Message for response to listing LbEdgeExtension resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations lb edge extensions list projects (response)
Fields
lb_edge_extensions: Option<Vec<LbEdgeExtension>>The list of LbEdgeExtension resources.
next_page_token: Option<String>A token identifying a page of results that the server returns.
unreachable: Option<Vec<String>>Locations that could not be reached.