pub struct ServiceLbPolicyAutoCapacityDrain {
pub enable: Option<bool>,
}Expand description
Option to specify if an unhealthy IG/NEG should be considered for global load balancing and traffic routing.
This type is not used in any activity, and only used as part of another schema.
Fields
enable: Option<bool>Optional. If set to ‘True’, an unhealthy IG/NEG will be set as drained. - An IG/NEG is considered unhealthy if less than 25% of the instances/endpoints in the IG/NEG are healthy. - This option will never result in draining more than 50% of the configured IGs/NEGs for the Backend Service.