pub struct ServiceLbPolicyIsolationConfig {
pub isolation_granularity: Option<String>,
pub isolation_mode: Option<String>,
}Expand description
Configuration to provide isolation support for the associated Backend Service.
This type is not used in any activity, and only used as part of another schema.
Fields
isolation_granularity: Option<String>Optional. The isolation granularity of the load balancer.
isolation_mode: Option<String>Optional. The isolation mode of the load balancer.