pub struct ExtensionChain {
pub extensions: Option<Vec<ExtensionChainExtension>>,
pub match_condition: Option<ExtensionChainMatchCondition>,
pub name: Option<String>,
}Expand description
A single extension chain wrapper that contains the match conditions and extensions to execute.
This type is not used in any activity, and only used as part of another schema.
Fields
extensions: Option<Vec<ExtensionChainExtension>>Required. A set of extensions to execute for the matching request. At least one extension is required. Up to 3 extensions can be defined for each extension chain for LbTrafficExtension resource. LbRouteExtension and LbEdgeExtension chains are limited to 1 extension per extension chain.
match_condition: Option<ExtensionChainMatchCondition>Required. Conditions under which this chain is invoked for a request.
name: Option<String>Required. The name for this extension chain. The name is logged as part of the HTTP request logs. The name must conform with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and can have a maximum length of 63 characters. Additionally, the first character must be a letter and the last a letter or a number.