pub struct HttpRouteHeaderModifier {
pub add: Option<HashMap<String, String>>,
pub remove: Option<Vec<String>>,
pub set: Option<HashMap<String, String>>,
}Expand description
The specification for modifying HTTP header in HTTP request and HTTP response.
This type is not used in any activity, and only used as part of another schema.
Fields
add: Option<HashMap<String, String>>Add the headers with given map where key is the name of the header, value is the value of the header.
remove: Option<Vec<String>>Remove headers (matching by header names) specified in the list.
set: Option<HashMap<String, String>>Completely overwrite/replace the headers with given map where key is the name of the header, value is the value of the header.