pub struct HttpRouteRouteMatch {
pub full_path_match: Option<String>,
pub headers: Option<Vec<HttpRouteHeaderMatch>>,
pub ignore_case: Option<bool>,
pub prefix_match: Option<String>,
pub query_parameters: Option<Vec<HttpRouteQueryParameterMatch>>,
pub regex_match: Option<String>,
}Expand description
RouteMatch defines specifications used to match requests. If multiple match types are set, this RouteMatch will match if ALL type of matches are matched.
This type is not used in any activity, and only used as part of another schema.
Fields
full_path_match: Option<String>The HTTP request path value should exactly match this value. Only one of full_path_match, prefix_match, or regex_match should be used.
headers: Option<Vec<HttpRouteHeaderMatch>>Specifies a list of HTTP request headers to match against. ALL of the supplied headers must be matched.
ignore_case: Option<bool>Specifies if prefix_match and full_path_match matches are case sensitive. The default value is false.
prefix_match: Option<String>The HTTP request path value must begin with specified prefix_match. prefix_match must begin with a /. Only one of full_path_match, prefix_match, or regex_match should be used.
query_parameters: Option<Vec<HttpRouteQueryParameterMatch>>Specifies a list of query parameters to match against. ALL of the query parameters must be matched.
regex_match: Option<String>The HTTP request path value must satisfy the regular expression specified by regex_match after removing any query parameters and anchor supplied with the original URL. For regular expression grammar, please see https://github.com/google/re2/wiki/Syntax Only one of full_path_match, prefix_match, or regex_match should be used.