pub struct HttpRouteStatefulSessionAffinityPolicy {
pub cookie_ttl: Option<Duration>,
}Expand description
The specification for cookie-based stateful session affinity where the date plane supplies a “session cookie” with the name “GSSA” which encodes a specific destination host and each request containing that cookie will be directed to that host as long as the destination host remains up and healthy. The gRPC proxyless mesh library or sidecar proxy will manage the session cookie but the client application code is responsible for copying the cookie from each RPC in the session to the next.
This type is not used in any activity, and only used as part of another schema.
Fields
Required. The cookie TTL value for the Set-Cookie header generated by the data plane. The lifetime of the cookie may be set to a value from 0 to 86400 seconds (24 hours) inclusive. Set this to 0s to use a session cookie and disable cookie expiration.