pub struct ServiceLbPolicyFailoverConfig {
pub failover_health_threshold: Option<i32>,
}Expand description
Option to specify health based failover behavior. This is not related to Network load balancer FailoverPolicy.
This type is not used in any activity, and only used as part of another schema.
Fields
failover_health_threshold: Option<i32>Optional. The percentage threshold that a load balancer will begin to send traffic to failover backends. If the percentage of endpoints in a MIG/NEG is smaller than this value, traffic would be sent to failover backends if possible. This field should be set to a value between 1 and 99. The default value is 50 for Global external HTTP(S) load balancer (classic) and Proxyless service mesh, and 70 for others.