pub struct TlsRouteRouteRule {
pub action: Option<TlsRouteRouteAction>,
pub matches: Option<Vec<TlsRouteRouteMatch>>,
}Expand description
Specifies how to match traffic and how to route traffic when traffic is matched.
This type is not used in any activity, and only used as part of another schema.
Fields
action: Option<TlsRouteRouteAction>Required. The detailed rule defining how to route matched traffic.
matches: Option<Vec<TlsRouteRouteMatch>>Required. RouteMatch defines the predicate used to match requests to a given action. Multiple match types are “OR“ed for evaluation. Atleast one RouteMatch must be supplied.