pub struct WasmPluginLogConfig {
pub enable: Option<bool>,
pub min_log_level: Option<String>,
pub sample_rate: Option<f32>,
}Expand description
Specifies the logging options for the activity performed by this plugin. If logging is enabled, plugin logs are exported to Cloud Logging.
This type is not used in any activity, and only used as part of another schema.
Fields
enable: Option<bool>Optional. Specifies whether to enable logging for activity by this plugin. Defaults to false.
min_log_level: Option<String>Non-empty default. Specifies the lowest level of the plugin logs that are exported to Cloud Logging. This setting relates to the logs generated by using logging statements in your Wasm code. This field is can be set only if logging is enabled for the plugin. If the field is not provided when logging is enabled, it is set to INFO by default.
sample_rate: Option<f32>Non-empty default. Configures the sampling rate of activity logs, where 1.0 means all logged activity is reported and 0.0 means no activity is reported. A floating point value between 0.0 and 1.0 indicates that a percentage of log messages is stored. The default value when logging is enabled is 1.0. The value of the field must be between 0 and 1 (inclusive). This field can be specified only if logging is enabled for this plugin.